@@ -15,21 +15,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include <config.h>
 
 #include <glib.h>
-#include <glib/gstdio.h>
 
 #include <glib/gi18n.h>
-#include <gtk/gtkmessagedialog.h>
+#include <glib/gstdio.h>
+#include <gtk/gtk.h>
 
 #include "downloader-view.h"
 #include "ephy-adblock-manager.h"
 #include "ephy-debug.h"
-#include "ephy-embed-factory.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
 #include "ephy-encodings.h"
@@ -229,10 +227,10 @@ impl_get_embed_single (EphyEmbedShell *shell)
 	if (priv->embed_single == NULL)
 	{
 		priv->embed_single = EPHY_EMBED_SINGLE
-			(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_SINGLE));
+                  (g_object_new (EPHY_TYPE_EMBED_SINGLE, NULL));
 		g_assert (priv->embed_single != NULL);
 
-		if (!ephy_embed_single_init (priv->embed_single))
+		if (!ephy_embed_single_initialize (priv->embed_single))
 		{
 			GtkWidget *dialog;
 
