@@ -13,11 +13,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-factory-action.h 6588 2006-09-13 11:34:25Z chpe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_BOOKMARK_FACTORY_ACTION_H
 #define EPHY_BOOKMARK_FACTORY_ACTION_H
 
@@ -25,8 +28,6 @@
 #include "ephy-window.h"
 
 #include <gtk/gtk.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
 
 #define EPHY_TYPE_BOOKMARK_FACTORY_ACTION            (ephy_bookmark_factory_action_get_type ())
 #define EPHY_BOOKMARK_FACTORY_ACTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_TYPE_BOOKMARK_FACTORY_ACTION, EphyBookmarkFactoryAction))
