@@ -25,7 +25,6 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
 #include "ephy-shell.h"
-#include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
 #include "ephy-debug.h"
 #include "ephy-command-manager.h"
@@ -93,7 +92,7 @@ window_cmd_file_print_preview (GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	ephy_embed_set_print_preview_mode (embed, TRUE);
+	ephy_web_view_set_print_preview_mode (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), TRUE);
 	_ephy_window_set_print_preview (window, TRUE);
 }
 
@@ -124,8 +123,8 @@ window_cmd_file_send_to	(GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
-	location = ephy_embed_get_address (embed);
-	title = ephy_embed_get_title (embed);
+	location = ephy_web_view_get_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
+	title = ephy_web_view_get_title (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 
 	subject = g_uri_escape_string (title, NULL, TRUE);
 	body = g_uri_escape_string (location, NULL, TRUE);
@@ -247,8 +246,8 @@ window_cmd_file_bookmark_page (GtkAction *action,
 	g_return_if_fail (embed != NULL);
 
 	ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (window),
-					ephy_embed_get_address (embed),
-					ephy_embed_get_title (embed));
+					ephy_web_view_get_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)),
+					ephy_web_view_get_title (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)));
 }
 
 static void
@@ -305,7 +304,7 @@ window_cmd_file_save_as (GtkAction *action,
 	g_return_if_fail (embed != NULL);
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+		(g_object_new (EPHY_TYPE_EMBED_PERSIST, NULL));
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_fc_title (persist, _("Save As"));
@@ -636,7 +635,7 @@ save_temp_source (EphyEmbed *embed,
 	}
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+		(g_object_new (EPHY_TYPE_EMBED_PERSIST, NULL));
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_COPY_PAGE |
@@ -665,7 +664,7 @@ window_cmd_view_page_source (GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
-	address = ephy_embed_get_address (embed);
+	address = ephy_web_view_get_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 	user_time = gtk_get_current_event_time ();
 
 	if (g_str_has_prefix (address, "file://"))
@@ -693,7 +692,7 @@ window_cmd_view_page_security_info (GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	ephy_embed_show_page_certificate (embed);
+	ephy_web_view_show_page_certificate (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 }
 
 void
@@ -721,7 +720,7 @@ window_cmd_edit_personal_data (GtkAction *action,
           (EPHY_EMBED_CONTAINER (window));
 	if (embed == NULL) return;
 
-	address = ephy_embed_get_address (embed);
+	address = ephy_web_view_get_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 	
 	host = address != NULL ? ephy_string_get_host_name (address) : NULL;
 
@@ -1029,5 +1028,5 @@ window_cmd_browse_with_caret (GtkAction *action,
 	gboolean active;
 
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_BROWSE_WITH_CARET, active);
+	eel_gconf_set_boolean (CONF_CARET_BROWSING_ENABLED, active);
 }
